@@ -1,7 +1,7 @@
 import os
 from .cassette import Cassette
 from .serializers import yamlserializer, jsonserializer
-from .matchers import method, url, host, path, headers, body
+from . import matchers
 
 
 class VCR(object):
@@ -9,7 +9,19 @@ class VCR(object):
                  serializer='yaml',
                  cassette_library_dir=None,
                  record_mode="once",
-                 match_on=['url', 'method'],
+                 filter_headers=[],
+                 filter_query_parameters=[],
+                 before_record=None,
+                 match_on=[
+                     'method',
+                     'scheme',
+                     'host',
+                     'port',
+                     'path',
+                     'query',
+                 ],
+                 ignore_hosts=[],
+                 ignore_localhost=False,
                  ):
         self.serializer = serializer
         self.match_on = match_on
@@ -19,14 +31,23 @@ class VCR(object):
             'json': jsonserializer,
         }
         self.matchers = {
-            'method': method,
-            'url': url,
-            'host': host,
-            'path': path,
-            'headers': headers,
-            'body': body,
+            'method': matchers.method,
+            'uri': matchers.uri,
+            'url': matchers.uri,  # matcher for backwards compatibility
+            'scheme': matchers.scheme,
+            'host': matchers.host,
+            'port': matchers.port,
+            'path': matchers.path,
+            'query': matchers.query,
+            'headers': matchers.headers,
+            'body': matchers.body,
         }
         self.record_mode = record_mode
+        self.filter_headers = filter_headers
+        self.filter_query_parameters = filter_query_parameters
+        self.before_record = before_record
+        self.ignore_hosts = ignore_hosts
+        self.ignore_localhost = ignore_localhost
 
     def _get_serializer(self, serializer_name):
         try:
@@ -65,6 +86,21 @@ class VCR(object):
             "serializer": self._get_serializer(serializer_name),
             "match_on": self._get_matchers(matcher_names),
             "record_mode": kwargs.get('record_mode', self.record_mode),
+            "filter_headers": kwargs.get(
+                'filter_headers', self.filter_headers
+            ),
+            "filter_query_parameters": kwargs.get(
+                'filter_query_parameters', self.filter_query_parameters
+            ),
+            "before_record": kwargs.get(
+                "before_record", self.before_record
+            ),
+            "ignore_hosts": kwargs.get(
+                'ignore_hosts', self.ignore_hosts
+            ),
+            "ignore_localhost": kwargs.get(
+                'ignore_localhost', self.ignore_localhost
+            ),
         }
 
         return Cassette.load(path, **merged_config)
